@@ -11,6 +11,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import socket
 import unittest
 
 from ironicclient import client
@@ -85,7 +86,7 @@ class TestCheckAuth(base.BaseTest):
         self.assertEqual('admin', args1['admin_user'])
         self.assertEqual('admin', args1['admin_tenant_name'])
         self.assertEqual('password', args1['admin_password'])
-        self.assertEqual(True, args1['delay_auth_decision'])
+        self.assertTrue(args1['delay_auth_decision'])
         self.assertEqual('http://127.0.0.1:5000/v2.0', args1['auth_uri'])
         self.assertEqual('http://127.0.0.1:35357', args1['identity_uri'])
 
@@ -138,28 +139,45 @@ class TestCheckAuth(base.BaseTest):
         utils.check_auth(request)
 
 
-@mock.patch('ironic_inspector.node_cache.NodeInfo')
 class TestGetIpmiAddress(base.BaseTest):
-    def test_ipv4_in_resolves(self, mock_node):
-        node = mock_node.return_value
-        node.driver_info.get.return_value = '192.168.1.1'
+    def test_ipv4_in_resolves(self):
+        node = mock.Mock(spec=['driver_info', 'uuid'],
+                         driver_info={'ipmi_address': '192.168.1.1'})
         ip = utils.get_ipmi_address(node)
         self.assertEqual(ip, '192.168.1.1')
 
     @mock.patch('socket.gethostbyname')
-    def test_good_hostname_resolves(self, mock_socket, mock_node):
-        node = mock_node.return_value
-        node.driver_info.get.return_value = 'www.example.com'
+    def test_good_hostname_resolves(self, mock_socket):
+        node = mock.Mock(spec=['driver_info', 'uuid'],
+                         driver_info={'ipmi_address': 'www.example.com'})
         mock_socket.return_value = '192.168.1.1'
         ip = utils.get_ipmi_address(node)
         mock_socket.assert_called_once_with('www.example.com')
         self.assertEqual(ip, '192.168.1.1')
 
-    def test_bad_hostname_errors(self, mock_node):
-        node = mock_node.return_value
-        node.driver_info.get.return_value = 'meow'
+    @mock.patch('socket.gethostbyname')
+    def test_bad_hostname_errors(self, mock_socket):
+        node = mock.Mock(spec=['driver_info', 'uuid'],
+                         driver_info={'ipmi_address': 'meow'},
+                         uuid='uuid1')
+        mock_socket.side_effect = socket.gaierror('Boom')
         self.assertRaises(utils.Error, utils.get_ipmi_address, node)
 
+    def test_additional_fields(self):
+        node = mock.Mock(spec=['driver_info', 'uuid'],
+                         driver_info={'foo': '192.168.1.1'})
+        self.assertIsNone(utils.get_ipmi_address(node))
+
+        CONF.set_override('ipmi_address_fields', ['foo', 'bar', 'baz'])
+        ip = utils.get_ipmi_address(node)
+        self.assertEqual(ip, '192.168.1.1')
+
+    def test_ipmi_bridging_enabled(self):
+        node = mock.Mock(spec=['driver_info', 'uuid'],
+                         driver_info={'ipmi_address': 'www.example.com',
+                                      'ipmi_bridging': 'single'})
+        self.assertIsNone(utils.get_ipmi_address(node))
+
 
 class TestCapabilities(unittest.TestCase):
 
@@ -195,3 +213,71 @@ class TestSpawnN(unittest.TestCase):
         greenpool.spawn_n.assert_called_with(func, "goodbye")
 
         mock_green_pool.assert_called_once_with(CONF.max_concurrency)
+
+
+class TestProcessingLogger(base.BaseTest):
+    def test_prefix_no_info(self):
+        self.assertEqual('[unidentified node]',
+                         utils.processing_logger_prefix())
+
+    def test_prefix_only_uuid(self):
+        node_info = mock.Mock(uuid='NNN')
+        self.assertEqual('[node: NNN]',
+                         utils.processing_logger_prefix(node_info=node_info))
+
+    def test_prefix_only_bmc(self):
+        data = {'inventory': {'bmc_address': '1.2.3.4'}}
+        self.assertEqual('[node: BMC 1.2.3.4]',
+                         utils.processing_logger_prefix(data=data))
+
+    def test_prefix_only_mac(self):
+        data = {'boot_interface': '01-aa-bb-cc-dd-ee-ff'}
+        self.assertEqual('[node: MAC aa:bb:cc:dd:ee:ff]',
+                         utils.processing_logger_prefix(data=data))
+
+    def test_prefix_everything(self):
+        node_info = mock.Mock(uuid='NNN')
+        data = {'boot_interface': '01-aa-bb-cc-dd-ee-ff',
+                'inventory': {'bmc_address': '1.2.3.4'}}
+        self.assertEqual('[node: NNN MAC aa:bb:cc:dd:ee:ff BMC 1.2.3.4]',
+                         utils.processing_logger_prefix(node_info=node_info,
+                                                        data=data))
+
+    def test_prefix_uuid_not_str(self):
+        node_info = mock.Mock(uuid=None)
+        self.assertEqual('[node: None]',
+                         utils.processing_logger_prefix(node_info=node_info))
+
+    def test_adapter_no_bmc(self):
+        CONF.set_override('log_bmc_address', False, 'processing')
+        node_info = mock.Mock(uuid='NNN')
+        data = {'boot_interface': '01-aa-bb-cc-dd-ee-ff',
+                'inventory': {'bmc_address': '1.2.3.4'}}
+        logger = utils.getProcessingLogger(__name__)
+        msg, _kwargs = logger.process('foo', {'node_info': node_info,
+                                              'data': data})
+        self.assertEqual(
+            '[node: NNN MAC aa:bb:cc:dd:ee:ff] foo',
+            msg)
+
+    def test_adapter_with_bmc(self):
+        node_info = mock.Mock(uuid='NNN')
+        data = {'boot_interface': '01-aa-bb-cc-dd-ee-ff',
+                'inventory': {'bmc_address': '1.2.3.4'}}
+        logger = utils.getProcessingLogger(__name__)
+        msg, _kwargs = logger.process('foo', {'node_info': node_info,
+                                              'data': data})
+        self.assertEqual(
+            '[node: NNN MAC aa:bb:cc:dd:ee:ff BMC 1.2.3.4] foo',
+            msg)
+
+    def test_adapter_empty_data(self):
+        logger = utils.getProcessingLogger(__name__)
+        msg, _kwargs = logger.process('foo', {'node_info': None,
+                                              'data': None})
+        self.assertEqual('[unidentified node] foo', msg)
+
+    def test_adapter_no_data(self):
+        logger = utils.getProcessingLogger(__name__)
+        msg, _kwargs = logger.process('foo', {})
+        self.assertEqual('foo', msg)
